@@ -1,9 +1,7 @@
 fill2col <-
-function(dat, upperboundText, showScale, neg) {
-	color <- colorRampPalette(brewer.pal(9,"Blues"),space="rgb")(101)
-	if (neg) {
-		color <- color[101:1]
-	}
+function(dat, showScale, palette) {
+	color <- colorRampPalette(palette,space="rgb")(101)
+
 	scale <- round(dat$value2)+1
 	
 	lineNpc <- convertHeight(unit(0.8,"lines"), "npc", valueOnly = TRUE)
@@ -23,7 +21,7 @@ function(dat, upperboundText, showScale, neg) {
 		grid.rect(x=unit(leg$X,"npc"), y=unit(leg$Y,"npc"), width=unit(leg$W,"npc"), height=unit(leg$H,"npc"), 
 			just=c("left","bottom"), gp = gpar(fill = as.character(leg$Col)))
 		grid.text(paste(legScale,"%",sep=""),x=unit(leg$X+.5*leg$W, "npc"),y=unit(0, "npc") + 
-			unit(0.5,"lines"),gp=gpar(cex=upperboundText*0.8))
+			unit(0.5,"lines"),gp=gpar(cex=0.8))
 	}
 	return (color[scale])
 }
